@@ -252,9 +252,9 @@ class DataFrameRegressionFixture:
             # Skip assertion if an array of strings
             if (array.dtype == "O") and (type(array.iloc[0]) is str):
                 continue
-            # Rejected: timedelta, datetime, objects, zero-terminated bytes, unicode strings and raw data
-            assert array.dtype.kind not in ["m", "M", "O", "S", "U", "V"], (
-                "Only numeric data is supported on dataframe_regression fixture.\n"
+            # Rejected: timedelta, objects, zero-terminated bytes, unicode strings and raw data
+            assert array.dtype.kind not in ["m", "O", "S", "U", "V"], (
+                "Only numeric data/datatime objects are supported on dataframe_regression fixture.\n"
                 "Array with type '%s' was given." % (str(array.dtype),)
             )
 
